SteelScript Wireshark
=====================

This package provides a command-line interface to query PCAP files through
``tshark`` and a datasource for App Framework to utilze Riverbed SteelCentral
Wireshark results. It is a part of the Riverbed SteelScript for Python.

Documentation available in this module:

* :doc:`installation`
* :doc:`getting-started`
* :doc:`pcap-api`
